@@ -2,7 +2,7 @@ var hierarchy =
 [
     [ "AuthPlugin", "classAuthPlugin.html", null ],
     [ "AwlCache", "classAwlCache.html", null ],
-    [ "AwlDBDialect", "classAwlDBDialect.html", [
+    [ "AwlDBDialect", null, [
       [ "AwlDatabase", "classAwlDatabase.html", null ]
     ] ],
     [ "AwlQuery", "classAwlQuery.html", null ],
@@ -22,7 +22,6 @@ var hierarchy =
     [ "MenuOption", "classMenuOption.html", null ],
     [ "MenuSet", "classMenuSet.html", null ],
     [ "Multipart", "classMultipart.html", null ],
-    [ "PgQuery", "classPgQuery.html", null ],
     [ "Session", "classSession.html", null ],
     [ "SinglePart", "classSinglePart.html", null ],
     [ "Validation", "classValidation.html", null ],
