@@ -3,6 +3,5 @@ var searchData=
   ['qdo_0',['QDo',['../classAwlQuery.html#a3b1c14d7ded4e60baa95aba58e365c6b',1,'AwlQuery']]],
   ['query_1',['query',['../classAwlDatabase.html#a845167b22ae1f581745e2656755d8b09',1,'AwlDatabase']]],
   ['querystring_2',['QueryString',['../classAwlQuery.html#af6eadadaa6e082ed8902aba952bb7ba2',1,'AwlQuery']]],
-  ['quote_3',['Quote',['../classAwlDBDialect.html#a8a5cf7a5a3dfbe966cab083d4ad525d0',1,'AwlDBDialect']]],
-  ['quote_4',['quote',['../classAwlQuery.html#ac58190b2243a9bf95b3119995a08aeb6',1,'AwlQuery\quote()'],['../classPgQuery.html#acaa79aa4efd07c55863025cfb78cfa35',1,'PgQuery\quote()']]]
+  ['quote_3',['quote',['../classAwlQuery.html#ac58190b2243a9bf95b3119995a08aeb6',1,'AwlQuery']]]
 ];
