@@ -1,11 +1,11 @@
 var indexSectionsWithContent =
 {
   0: "$_abcdefghilmnopqrstuvwx",
-  1: "abdeimpsuvx",
+  1: "abdeimsuvx",
   2: "a",
   3: "_abcdefghilmnopqrstuvw",
-  4: "$hs",
-  5: "dt"
+  4: "$",
+  5: "dlt"
 };
 
 var indexSectionNames =
